import React from 'react';
import { PREFIX_CLS } from "../constants/dictionary";
import { Icon, Button, Typography, Divider, Tooltip } from 'rlj-design';
import HighLight from "../HighLight";
import "./style/leftContain.less";
import { useStoreContext } from "./hooks/useStoreContext";
import { getHandleData } from "./common";
import ShowTag from "./showTag";
var Text = Typography.Text,
    TextOverFlow = Typography.TextOverFlow;
var prefixCls = "".concat(PREFIX_CLS, "-DPPicker-listContainWrap");

var LeftContain = function LeftContain(props) {
  var item = props.item,
      canChange = props.canChange,
      isSelect = props.isSelect,
      isDisabled = props.isDisabled;

  var _useStoreContext = useStoreContext(),
      searchValue = _useStoreContext.searchValue,
      recurse = _useStoreContext.recurse,
      getList = _useStoreContext.getList,
      setLeftPartList = _useStoreContext.setLeftPartList,
      setBreadcrumbList = _useStoreContext.setBreadcrumbList,
      breadcrumbList = _useStoreContext.breadcrumbList;

  var nodeType = item.nodeType,
      deptName = item.deptName,
      orgId = item.orgId,
      haveChildren = item.haveChildren,
      iconType = item.iconType,
      orgChain = item.orgChain,
      code = item.code,
      tagStatus = item.tagStatus,
      employeeNumber = item.employeeNumber;
  var disabledSelect = isSelect && recurse || isDisabled; // 所有禁用状态

  var leftIcon = isDisabled ? 'disabledIcon' : 'leftIcon';
  var searchIcon = isDisabled ? 'disabledSearchIcon' : 'searchIcon';
  var listText = "".concat(prefixCls, "-listText");
  var showTag = tagStatus === 'quitted' || tagStatus === 'disable';
  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("span", {
    className: "".concat(prefixCls)
  }, /*#__PURE__*/React.createElement("span", {
    className: "".concat(listText)
  }, /*#__PURE__*/React.createElement(Icon, {
    type: iconType,
    style: {
      borderRadius: nodeType === 1 ? '50%' : 4,
      color: isDisabled ? '#99b9f2' : '#0050de'
    },
    className: canChange ? "".concat(listText, "-").concat(searchIcon) : "".concat(listText, "-").concat(leftIcon)
  }), !canChange ? /*#__PURE__*/React.createElement("span", {
    className: "".concat(listText, "-listNameWrap")
  }, /*#__PURE__*/React.createElement("span", {
    className: "".concat(listText, "-deptNameWraps")
  }, /*#__PURE__*/React.createElement(TextOverFlow, null, deptName)), showTag && /*#__PURE__*/React.createElement(ShowTag, {
    item: item
  })) : /*#__PURE__*/React.createElement("span", {
    className: "".concat(prefixCls, "-listTextWrap")
  }, /*#__PURE__*/React.createElement("span", {
    style: {
      display: 'flex',
      alignItems: 'center'
    }
  }, /*#__PURE__*/React.createElement(Text, {
    className: "".concat(prefixCls, "-listTextWrap-deptName"),
    style: isDisabled && {
      color: '#b6b6ba'
    },
    ellipsis: {
      tooltip: {
        deptName: deptName
      }
    }
  }, /*#__PURE__*/React.createElement(HighLight, {
    highLightText: searchValue
  }, deptName ? deptName : '')), showTag && /*#__PURE__*/React.createElement(ShowTag, {
    item: item
  }), /*#__PURE__*/React.createElement("span", {
    className: "".concat(prefixCls, "-listTextWrap-codeWrap")
  }, /*#__PURE__*/React.createElement(Tooltip, {
    placement: "top",
    title: isDisabled ? '' : code || employeeNumber
  }, /*#__PURE__*/React.createElement("div", {
    className: "".concat(prefixCls, "-listTextWrap-code")
  }, code || employeeNumber)))), /*#__PURE__*/React.createElement(Text, {
    className: "".concat(prefixCls, "-listTextWrap-chain"),
    style: isDisabled && {
      color: '#b6b6ba'
    },
    ellipsis: {
      tooltip: {
        orgChain: orgChain
      }
    }
  }, /*#__PURE__*/React.createElement(HighLight, {
    highLightText: searchValue
  }, orgChain ? orgChain : '')))), !canChange && haveChildren && !searchValue && /*#__PURE__*/React.createElement("span", {
    className: "".concat(prefixCls, "-recuseBtnWap")
  }, /*#__PURE__*/React.createElement(Divider, {
    type: "vertical"
  }), /*#__PURE__*/React.createElement(Button, {
    disabled: disabledSelect,
    type: "link",
    noPadding: true,
    style: {
      marginLeft: 4
    },
    className: disabledSelect ? "".concat(prefixCls, "-recuseBtnWap-recuseBtn") : "".concat(prefixCls, "-recuseBtnWap-Btn"),
    onClick: function onClick(e) {
      var _item$children;

      e.preventDefault();
      setBreadcrumbList(breadcrumbList.concat(item));

      if (((_item$children = item.children) === null || _item$children === void 0 ? void 0 : _item$children.length) > 0) {
        var newArr = getHandleData(item.children);
        setLeftPartList(newArr);
      } else {
        getList(orgId);
      }
    }
  }, "\u4E0B\u7EA7"))));
};

export default LeftContain;