function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React, { useCallback, useEffect, useRef } from 'react';
import { Icon, Tag } from 'rlj-design';
import classnames from 'classnames';
import { DndProvider } from 'react-dnd';
import { HTML5Backend } from 'react-dnd-html5-backend';
import { DragDropContext, Droppable, Draggable } from 'react-beautiful-dnd';
import { useStoreContext } from "../hooks";
import { PREFIX_CLS } from "../../constants/dictionary";
import TagItem, { moveTagItem } from "./TagItem";
var prefixCls = "".concat(PREFIX_CLS, "-fieldMultiDrag");

var FieldItem = function FieldItem(props) {
  var groupName = props.groupName,
      children = props.children,
      groupId = props.groupId,
      fieldId = props.fieldId;

  var _useStoreContext = useStoreContext(),
      setCheckedValueMap = _useStoreContext.setCheckedValueMap,
      checkedValueMap = _useStoreContext.checkedValueMap,
      isMultipleDragGroup = _useStoreContext.isMultipleDragGroup;

  var key = isMultipleDragGroup ? groupId || fieldId || '' : 'group';

  var closeTag = function closeTag(id) {
    var mapKey = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : key;
    return function () {
      var _checkedValueMap$get;

      var key = isMultipleDragGroup ? mapKey : 'group';
      var restValue = (_checkedValueMap$get = checkedValueMap.get(key)) === null || _checkedValueMap$get === void 0 ? void 0 : _checkedValueMap$get.filter(function (item) {
        return !item.includes(id);
      });

      if (restValue !== null && restValue !== void 0 && restValue.length) {
        checkedValueMap.set(key, restValue);
      } else {
        checkedValueMap.delete(key);
      }

      setCheckedValueMap(new Map(checkedValueMap));
    }();
  };

  var dropHandle = useCallback(function (item, index) {
    var temp = item.checkedValueMap.get(key) || [];
    checkedValueMap.set(key, moveTagItem(temp, item, index));
    setCheckedValueMap(new Map(checkedValueMap));
  }, [checkedValueMap]);

  var getTagList = function getTagList() {
    return children === null || children === void 0 ? void 0 : children.map(function (item, index) {
      return /*#__PURE__*/React.createElement(TagItem, _extends({
        key: item === null || item === void 0 ? void 0 : item.fieldId
      }, item, {
        index: index,
        closeTag: closeTag,
        dropHandle: dropHandle,
        type: key
      }));
    });
  };

  return /*#__PURE__*/React.createElement(React.Fragment, null, isMultipleDragGroup ? /*#__PURE__*/React.createElement("div", {
    className: "".concat(prefixCls, "-item")
  }, /*#__PURE__*/React.createElement("div", {
    className: "".concat(prefixCls, "-item-title")
  }, groupName), getTagList()) : getTagList());
};

var FieldGroupItem = function FieldGroupItem(props) {
  var _children$;

  var groupName = props.groupName,
      children = props.children,
      groupDisabled = props.groupDisabled;
  return /*#__PURE__*/React.createElement("div", {
    className: classnames("".concat(prefixCls, "-groupItem"), _defineProperty({}, "".concat(prefixCls, "-groupItem-disabled"), groupDisabled))
  }, /*#__PURE__*/React.createElement(Icon, {
    type: "draggable",
    color: "#7f7f85"
  }), /*#__PURE__*/React.createElement("div", {
    className: "".concat(prefixCls, "-groupItem-title")
  }, groupName || /*#__PURE__*/React.createElement(Tag, {
    type: "selected",
    height: 24,
    style: {
      color: '#7f7f85',
      padding: '0 8px'
    }
  }, children === null || children === void 0 ? void 0 : (_children$ = children[0]) === null || _children$ === void 0 ? void 0 : _children$.fieldName)));
};

export var FieldMultipleDrag = function FieldMultipleDrag() {
  var _useStoreContext2 = useStoreContext(),
      defaultSelectFields = _useStoreContext2.defaultSelectFields,
      selectFields = _useStoreContext2.selectFields,
      setCheckedValueMap = _useStoreContext2.setCheckedValueMap,
      checkedValueMap = _useStoreContext2.checkedValueMap,
      groupSort = _useStoreContext2.groupSort,
      setSelectAllFields = _useStoreContext2.setSelectAllFields,
      selectAllFields = _useStoreContext2.selectAllFields,
      isMultipleDragGroup = _useStoreContext2.isMultipleDragGroup;

  var ref = useRef(null);
  useEffect(function () {
    if (!defaultSelectFields) return;
    defaultSelectFields.forEach(function (item) {
      var _ref = item || {},
          children = _ref.children,
          groupId = _ref.groupId,
          fieldId = _ref.fieldId;

      children = groupId ? children : [item];
      var key = isMultipleDragGroup ? groupId || fieldId : 'group';

      if (!isMultipleDragGroup) {
        var _children, _children2;

        var fieldList = checkedValueMap.get(key) || [];
        ((_children = children) === null || _children === void 0 ? void 0 : _children.length) && checkedValueMap.set(key, fieldList.concat((_children2 = children) === null || _children2 === void 0 ? void 0 : _children2.map(function (_ref2) {
          var fieldId = _ref2.fieldId;
          return fieldId;
        })));
      } else {
        var _children3, _children4;

        ((_children3 = children) === null || _children3 === void 0 ? void 0 : _children3.length) && checkedValueMap.set(key, (_children4 = children) === null || _children4 === void 0 ? void 0 : _children4.map(function (_ref3) {
          var fieldId = _ref3.fieldId;
          return fieldId;
        }));
      }
    });
    setCheckedValueMap(new Map(checkedValueMap));
  }, [defaultSelectFields]);

  var reorder = function reorder(list, startIndex, endIndex) {
    var result = Array.from(list);

    var _result$splice = result.splice(startIndex, 1),
        _result$splice2 = _slicedToArray(_result$splice, 1),
        removed = _result$splice2[0];

    result.splice(endIndex, 0, removed);
    return result;
  };

  var onDragEnd = function onDragEnd(result) {
    if (!result.destination || result.destination.index === result.source.index) {
      return;
    }

    var quotes = result ? reorder(selectFields, result.source.index, result.destination.index) : selectFields;
    checkedValueMap.clear();
    quotes.forEach(function (_ref4) {
      var groupId = _ref4.groupId,
          fieldId = _ref4.fieldId,
          children = _ref4.children;

      if (children !== null && children !== void 0 && children.length) {
        checkedValueMap.set(groupId || fieldId, children.map(function (item) {
          return item.fieldId;
        }));
      }
    });
    setCheckedValueMap(checkedValueMap);
    setSelectAllFields(quotes);
  };

  var getQuoteList = function getQuoteList() {
    return selectFields.map(function (item, index) {
      return /*#__PURE__*/React.createElement(Draggable, {
        key: "id-".concat(index),
        isDragDisabled: item.groupDisabled,
        draggableId: "id-".concat(index),
        index: index,
        style: {
          marginBottom: 12
        }
      }, function (provided) {
        return /*#__PURE__*/React.createElement("div", _extends({
          ref: provided.innerRef
        }, provided.draggableProps, provided.dragHandleProps), /*#__PURE__*/React.createElement(FieldGroupItem, _extends({
          key: (item === null || item === void 0 ? void 0 : item.groupId) || item.fieldId
        }, item)));
      });
    });
  };

  return /*#__PURE__*/React.createElement(React.Fragment, null, groupSort ? /*#__PURE__*/React.createElement(DragDropContext, {
    onDragEnd: onDragEnd
  }, /*#__PURE__*/React.createElement(Droppable, {
    droppableId: "list-drag"
  }, function (provided) {
    return /*#__PURE__*/React.createElement("div", _extends({
      ref: provided.innerRef
    }, provided.droppableProps), /*#__PURE__*/React.createElement("div", {
      ref: ref
    }, getQuoteList(), provided.placeholder));
  })) : /*#__PURE__*/React.createElement(DndProvider, {
    backend: HTML5Backend
  }, /*#__PURE__*/React.createElement("div", {
    className: prefixCls
  }, selectAllFields === null || selectAllFields === void 0 ? void 0 : selectAllFields.map(function (item) {
    return /*#__PURE__*/React.createElement(FieldItem, _extends({
      key: (item === null || item === void 0 ? void 0 : item.groupId) || item.fieldId
    }, item));
  }))));
};